==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/SplineFragmentBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let SplineFragmentBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineFragmentBaseDescriptionMetadata extends Base {
        static b(a) {
            if (SplineFragmentBaseDescriptionMetadata.a == null) {
                SplineFragmentBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineFragmentBaseDescriptionMetadata.c(SplineFragmentBaseDescriptionMetadata.a);
            }
            if (a.k(SplineFragmentBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(SplineFragmentBaseDescriptionMetadata.a);
        }
        static c(a) {
            SplineSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineFragmentBaseDescriptionMetadata.b(a);
            a.ac("SplineFragmentBase", SplineFragmentBaseDescriptionMetadata.a);
        }
    }
    SplineFragmentBaseDescriptionMetadata.$t = markType(SplineFragmentBaseDescriptionMetadata, 'SplineFragmentBaseDescriptionMetadata');
    SplineFragmentBaseDescriptionMetadata.a = null;
    return SplineFragmentBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/SplineFragmentBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let SplineFragmentBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineFragmentBaseDescriptionMetadata extends Base {
        static b(a) {
            if (SplineFragmentBaseDescriptionMetadata.a == null) {
                SplineFragmentBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineFragmentBaseDescriptionMetadata.c(SplineFragmentBaseDescriptionMetadata.a);
            }
            if (a.k(SplineFragmentBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(SplineFragmentBaseDescriptionMetadata.a);
        }
        static c(a) {
            SplineSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineFragmentBaseDescriptionMetadata.b(a);
            a.ad("SplineFragmentBase", SplineFragmentBaseDescriptionMetadata.a);
        }
    }
    SplineFragmentBaseDescriptionMetadata.$t = markType(SplineFragmentBaseDescriptionMetadata, 'SplineFragmentBaseDescriptionMetadata');
    SplineFragmentBaseDescriptionMetadata.a = null;
    return SplineFragmentBaseDescriptionMetadata;
})();
